WebBrowser/WebBrowserClearPrivateDataDialog.py

branch
QtWebEngine
changeset 4819
cb0672f0fc15
parent 4741
f9e1adc69076
child 5389
9b1c800daff3
--- a/WebBrowser/WebBrowserClearPrivateDataDialog.py	Sun Mar 06 17:24:27 2016 +0100
+++ b/WebBrowser/WebBrowserClearPrivateDataDialog.py	Sun Mar 06 17:45:24 2016 +0100
@@ -38,9 +38,9 @@
         
         @return tuple with flags indicating which data to clear
             (browsing history, search history, favicons, disk cache, cookies,
-            passwords, web databases, downloads, flash, zoom values) and the
-            selected history period in milliseconds (tuple of booleans and
-            integer)
+            passwords, web databases, downloads, flash, zoom values, SSL
+            certificate error exceptions) and the selected history period in
+            milliseconds (tuple of booleans and integer)
         """
         index = self.historyCombo.currentIndex()
         if index == 0:
@@ -69,4 +69,5 @@
                 self.downloadsCheckBox.isChecked(),
                 self.flashCookiesCheckBox.isChecked(),
                 self.zoomCheckBox.isChecked(),
+                self.sslExceptionsCheckBox.isChecked(),
                 historyPeriod)

eric ide

mercurial